@@ -4,16 +4,17 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 """
-Whenever the requirements in ../setup_requirements.py are updated,
-run also this script to update the requirements for Read the Docs.
+Whenever the requirements in ../setup.json are updated, run
+also this script to update the requirements for Read the Docs.
 """
-import sys
+
 import os
+import json
 import click
 
 
@@ -22,20 +23,15 @@ import click
 def update_req_for_rtd(pre_commit):
     """Update the separate requirements file for Read the Docs"""
     docs_dir = os.path.abspath(os.path.dirname(__file__))
-    sys.path.append(os.path.join(docs_dir, os.pardir))
+    root_dir = os.path.join(docs_dir, os.pardir)
 
-    import setup_requirements
+    with open(os.path.join(root_dir, 'setup.json'), 'r') as info:
+        setup_json = json.load(info)
 
-    reqs = set(setup_requirements.extras_require['docs'] +
-               setup_requirements.extras_require['rest'] +
-               setup_requirements.extras_require['testing'] +
-               setup_requirements.extras_require[':python_version < "3"'] +
-               # To avoid that it requires also the postgres libraries
-               [
-                   p for p in setup_requirements.install_requires
-                   if not p.startswith('psycopg2')
-               ])
-    reqs_str = "\n".join(sorted(reqs))
+    extras = setup_json['extras_require']
+    reqs = set(extras['testing'] + extras['docs'] + extras['rest'] + extras['atomic_tools'] +
+        setup_json['install_requires'])
+    reqs_str = '\n'.join(sorted(reqs))
 
     basename = 'requirements_for_rtd.txt'
 
@@ -49,8 +45,7 @@ def update_req_for_rtd(pre_commit):
         msg = 'Some requirements for Read the Docs have changed, {}'
         local_help = 'please add the changes and commit again'
         travis_help = 'please run aiida/docs/update_req_for_rtd.py locally and commit the changes it makes'
-        help_msg = msg.format(
-            travis_help if os.environ.get('TRAVIS') else local_help)
+        help_msg = msg.format(travis_help if os.environ.get('TRAVIS') else local_help)
         click.echo(help_msg, err=True)
 
 
