@@ -4,26 +4,24 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-from aiida.orm.data.base import Float, Int, NumericType
-from aiida.work.run import run
-from aiida.work.workchain import WorkChain
+"""
+This example illustrates in a very minimal way how a WorkChain can be defined and how it can be run. This mostly
+illustrates how the spec of the WorkChain is defined and how functions in the outline of the spec have to be defined.
+"""
 
-"""
-This example illustrates in a very minimal way how a WorkChain can be defined
-and how it can be run. This mostly illustrates how the spec of the WorkChain
-is defined and how functions in the outline of the spec have to be defined.
-"""
+from aiida.engine import WorkChain, run
+from aiida.orm import NumericType, Float, Int
 
 
 class SumWorkChain(WorkChain):
 
     @classmethod
     def define(cls, spec):
-        super(SumWorkChain, cls).define(spec)
+        super().define(spec)
         spec.input('a', valid_type=NumericType)
         spec.input('b', valid_type=NumericType)
         spec.outline(
@@ -39,7 +37,7 @@ class ProductWorkChain(WorkChain):
 
     @classmethod
     def define(cls, spec):
-        super(ProductWorkChain, cls).define(spec)
+        super().define(spec)
         spec.input('a', valid_type=NumericType)
         spec.input('b', valid_type=NumericType)
         spec.outline(
@@ -49,13 +47,13 @@ class ProductWorkChain(WorkChain):
 
     def product(self):
         self.out('product', self.inputs.a * self.inputs.b)
-    
+
 
 class SumProductWorkChain(WorkChain):
 
     @classmethod
     def define(cls, spec):
-        super(SumProductWorkChain, cls).define(spec)
+        super().define(spec)
         spec.input('a', valid_type=NumericType)
         spec.input('b', valid_type=NumericType)
         spec.input('c', valid_type=NumericType)
@@ -80,14 +78,14 @@ def main():
     }
 
     results = run(SumWorkChain, **inputs)
-    print 'Result of SumWorkChain: {}'.format(results)
+    print('Result of SumWorkChain: {}'.format(results))
 
     results = run(ProductWorkChain, **inputs)
-    print 'Result of ProductWorkChain: {}'.format(results)
+    print('Result of ProductWorkChain: {}'.format(results))
 
     results = run(SumProductWorkChain, **inputs)
-    print 'Result of SumProductWorkChain: {}'.format(results)
+    print('Result of SumProductWorkChain: {}'.format(results))
 
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
