@@ -4,26 +4,24 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-from aiida.orm.data.base import Int
-from aiida.work.run import run
-from aiida.work.workchain import WorkChain, while_, if_
+"""
+This WorkChain example is a very contrived implementation of the infamous FizzBuzz problem, that serves to illustrate
+the various logical blocks that one can incorporate into the outline of the workchain's spec.
+"""
 
-"""
-This WorkChain example is a very contrived implementation of the infamous FizzBuzz
-problem, that serves to illustrate the various logical blocks that one can incorporate
-into the outline of the workchain's spec.
-"""
+from aiida.engine import WorkChain, run, while_, if_
+from aiida.orm import Int
 
 
 class OutlineWorkChain(WorkChain):
 
     @classmethod
     def define(cls, spec):
-        super(OutlineWorkChain, cls).define(spec)
+        super().define(spec)
         spec.input('a', valid_type=Int)
         spec.outline(
             cls.setup,
@@ -57,24 +55,24 @@ class OutlineWorkChain(WorkChain):
         return self.ctx.counter % 3 == 0
 
     def report_fizz_buzz(self):
-        print 'FizzBuzz'
+        print('FizzBuzz')
 
     def report_fizz(self):
-        print 'Fizz'
+        print('Fizz')
 
     def report_buzz(self):
-        print 'Buzz'
+        print('Buzz')
 
     def report_number(self):
-        print self.ctx.counter
+        print(self.ctx.counter)
 
     def decrement(self):
         self.ctx.counter -= 1
 
 
 def main():
-    results = run(OutlineWorkChain, a=Int(16))
+    run(OutlineWorkChain, a=Int(16))
 
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
